<?php
/**
 * ownCloud
 *
 * @author Artur Neumann <info@jankaritech.com>
 * @copyright Copyright (c) 2017 Artur Neumann info@jankaritech.com
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU AFFERO GENERAL PUBLIC LICENSE
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU AFFERO GENERAL PUBLIC LICENSE for more details.
 *
 * You should have received a copy of the GNU Affero General Public
 * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
namespace TestHelpers\Firewall;
use Behat\Gherkin\Node\TableNode;
use GuzzleHttp\Psr7\Request;
use PHPUnit\Framework\Assert;
use TestHelpers\SetupHelper;

/**
 * Helper for generic firewall actions
 *
 */
class FirewallHelper {

	/**
	 * deletes all firewall rules from the config array and re-writes the config.php
	 *
	 * @return string[]
	 */
	public static function deleteAllFirewallRules() {
		return SetupHelper::runOcc(['config:system:delete','firewall.rules']);
	}

	/**
	 * asserts that the statusCode is a one that shows success (from 200 to 204)
	 *
	 * @param int $statusCode
	 * @param string $message
	 * @return void
	 */
	public static function assertHttpSuccess($statusCode, $message) {
		Assert::assertGreaterThanOrEqual(
			200, $statusCode, $message
		);
		Assert::assertLessThanOrEqual(
			204, $statusCode, $message
		);
	}

	/**
	 * asserts that the statusCode is forbidden (403)
	 *
	 * @param int $statusCode
	 * @param string $message
	 * @return void
	 */
	public static function assertHttpForbidden($statusCode, $message) {
		Assert::assertEquals(403, $statusCode, $message);
	}

	/**
	 * asserts that the statusCode is like expected
	 * if $possible is true then the statusCode should be one from 200 to 204
	 * else 403
	 *
	 * @param boolean $possible
	 * @param int $statusCode
	 * @param string $message
	 * @return void
	 */
	public static function assertHttpResultCorrect(
		$possible, $statusCode, $message
	) {
		if ($possible) {
			self::assertHttpSuccess($statusCode, $message);
		} else {
			self::assertHttpForbidden($statusCode, $message);
		}
	}

	/**
	 * sets the headers to a request from a behat table.
	 * Returns the modified Request
	 *
	 * @param null|TableNode $headersTable table of headers to be set for the upload
	 * table headings: must be: |http-header    |value|
	 * @return array
	 */
	public static function createHttpRequestHeadersArray($headersTable) {
		$result = [];
		if ($headersTable !== null) {
			foreach ($headersTable as $header) {
				$result[$header["http-header"]] = $header["value"];
			}
		}
		return $result;
	}
}
