@webUI
Feature: LimitFileAccessBasedOnRequestURL

  Background:
    Given the administrator has logged in using the webUI
    And the user has browsed to the File Firewall settings page
    And the user has created an empty firewall rule group named "requesturl-limiter"
    And these users have been created with skeleton files:
      | username |
      | Alice    |
    And user "Alice" has created folder "test_folder"
    And user "Alice" has copied file "lorem.txt" to "test_folder/lorem.txt"
    And user "Alice" has copied file "testimage.gif" to "test_folder/testimage.gif"
    And user "Alice" has created a public link share of file "test_folder"

  Scenario: prohibit file access based on specific Request URL
    When the user places a rule with the filter "Request URL", the operator "is" and the value "%base_url%/remote.php/dav/files/Alice/lorem.txt" in the group named "requesturl-limiter"
    And the user saves the firewall rules
    Then it should be possible for user "Alice" to download the file "data.zip" using "v2" dav path
    But it should not be possible for user "Alice" to download the file "lorem.txt" using "v2" dav path
    And it should be possible to download the file "testimage.gif" through the last created public link

  Scenario: prohibit file access based on specific Request URL (same as above but reverse order)
    When the user places a rule with the filter "Request URL", the operator "is" and the value "%base_url%/remote.php/dav/files/Alice/lorem.txt" in the group named "requesturl-limiter"
    And the user saves the firewall rules
    Then it should not be possible for user "Alice" to download the file "lorem.txt" using "v2" dav path
    But it should be possible for user "Alice" to download the file "data.zip" using "v2" dav path
    And it should be possible to download the file "testimage.gif" through the last created public link

  Scenario: prohibit file access except for one specific Request URL
    When the user places a rule with the filter "Request URL", the operator "is not" and the value "%base_url%/remote.php/dav/files/Alice/data.zip" in the group named "requesturl-limiter"
    And the user saves the firewall rules
    Then it should be possible for user "Alice" to download the file "data.zip" using "v2" dav path
    But it should not be possible for user "Alice" to download the file "lorem.txt" using "v2" dav path
    And it should not be possible to download the file "testimage.gif" through the last created public link

  Scenario: prohibit file access by Request URLs beginning with a specific string
    When the user places a rule with the filter "Request URL", the operator "begins with" and the value "%base_url%/remote.php/dav/files/Alice/data" in the group named "requesturl-limiter"
    And the user saves the firewall rules
    Then it should be possible for user "Alice" to download the file "lorem.txt" using "v2" dav path
    But it should not be possible for user "Alice" to download the file "data.zip" using "v2" dav path
    And it should not be possible for user "Alice" to download the file "data.tar.gz" using "v2" dav path
    And it should be possible to download the file "testimage.gif" through the last created public link

  Scenario: prohibit file access by Request URLs not beginning with a specific string
    When the user places a rule with the filter "Request URL", the operator "doesn't begin with" and the value "%base_url%/remote.php/dav/files/Alice/data" in the group named "requesturl-limiter"
    And the user saves the firewall rules
    Then it should be possible for user "Alice" to download the file "data.zip" using "v2" dav path
    And it should be possible for user "Alice" to download the file "data.tar.gz" using "v2" dav path
    But it should not be possible for user "Alice" to download the file "lorem.txt" using "v2" dav path
    And it should not be possible to download the file "testimage.gif" through the last created public link

  Scenario: prohibit file access by Request URLs containing a specific string
    When the user places a rule with the filter "Request URL", the operator "contains" and the value "app" in the group named "requesturl-limiter"
    And the user saves the firewall rules
    Then it should be possible for user "Alice" to download the file "testimage.gif" using "any" dav path
    But it should not be possible for user "Alice" to download the file "desktopapp.png" using "any" dav path
    And it should not be possible for user "Alice" to download the file "testapp2.zip" using "any" dav path

  Scenario: prohibit file access by Request URLs not containing a specific string
    When the user places a rule with the filter "Request URL", the operator "doesn't contain" and the value "image" in the group named "requesturl-limiter"
    And the user saves the firewall rules
    Then it should be possible for user "Alice" to download the file "testimagelarge.svg" using "any" dav path
    And it should be possible for user "Alice" to download the file "testimage.odt" using "any" dav path
    But it should not be possible for user "Alice" to download the file "lorem.txt" using "any" dav path
    And it should be possible to download the file "testimage.gif" through the last created public link
    But it should not be possible to download the file "lorem.txt" through the last created public link

  Scenario: prohibit file access by Request URLs ending with a specific string
    When the user places a rule with the filter "Request URL", the operator "ends with" and the value "gif" in the group named "requesturl-limiter"
    And the user saves the firewall rules
    Then it should be possible for user "Alice" to download the file "testimage.jpg" using "any" dav path
    But it should not be possible for user "Alice" to download the file "testimage.gif" using "any" dav path
    And it should be possible to download the file "lorem.txt" through the last created public link
    But it should not be possible to download the file "testimage.gif" through the last created public link

  Scenario: prohibit file access by Request URLs not ending with a specific string
    When the user places a rule with the filter "Request URL", the operator "doesn't end with" and the value ".txt" in the group named "requesturl-limiter"
    And the user saves the firewall rules
    Then it should be possible for user "Alice" to download the file "lorem-big.txt" using "any" dav path
    But it should not be possible for user "Alice" to download the file "testavatar.png" using "any" dav path
    And it should not be possible to download the file "testimage.gif" through the last created public link
    But it should be possible to download the file "lorem.txt" through the last created public link
