@webUI
Feature: LimitUploadBasedOnMimeType

  Background:
    Given the administrator has logged in using the webUI
    And the user has browsed to the File Firewall settings page
    And the user has created an empty firewall rule group named "mime-limiter"
    And user "Alice" has been created with default attributes and skeleton files
    And user "Alice" has created a public link share of file "simple-folder" with uploadwriteonly permissions

  Scenario: prohibit file upload for files of a certain mime type
    When the user places a rule with the filter "File mimetype upload", the operator "is" and the value "text/plain" in the group named "mime-limiter"
    And the user saves the firewall rules
    Then it should not be possible to upload a file with the mime-type "text/plain" using "any" dav path
    But it should be possible to upload a file with the mime-type "image/jpeg" using "any" dav path

  Scenario: prohibit file upload for files of a certain mime type (use chunking to upload)
    When the user places a rule with the filter "File mimetype upload", the operator "is" and the value "text/plain" in the group named "mime-limiter"
    And the user saves the firewall rules
    Then it should not be possible to upload a file with the mime-type "text/plain" using "any" dav path and v1 chunking

  Scenario: prohibit file upload for files of a certain mime type (use chunking to upload)
    When the user places a rule with the filter "File mimetype upload", the operator "is" and the value "text/plain" in the group named "mime-limiter"
    And the user saves the firewall rules
    Then it should not be possible to upload a file with the mime-type "text/plain" using "v2" dav path and v2 chunking

  Scenario: prohibit file upload for files of a certain mime type (use async move to upload)
    Given the user has placed a rule with the filter "File mimetype upload", the operator "is" and the value "text/plain" in the group named "mime-limiter"
    And the user has saved the firewall rules
    And using new DAV path
    And the administrator has enabled async operations
    And user "Brian" has been created with default attributes and skeleton files
    When user "Brian" uploads the following chunks asynchronously to "/myChunkedFile.txt" with new chunking and using the WebDAV API
      | number | content |
      | 1      | AAAAA   |
      | 2      | BBBBB   |
      | 3      | CCCCC   |
    Then as "Brian" file "/myChunkedFile.txt" should not exist

  Scenario: prohibit file upload for files that are not of a certain mime type
    When the user places a rule with the filter "File mimetype upload", the operator "is not" and the value "image/bmp" in the group named "mime-limiter"
    And the user saves the firewall rules
    Then it should be possible to upload a file with the mime-type "image/bmp" using "any" dav path
    But it should not be possible to upload a file with the mime-type "application/msword" using "any" dav path

  Scenario: prohibit file upload for files whose mime type begins with a specific string
    When the user places a rule with the filter "File mimetype upload", the operator "begins with" and the value "video" in the group named "mime-limiter"
    And the user saves the firewall rules
    Then it should be possible to upload a file with the mime-type "image/bmp" using "any" dav path
    And it should be possible to upload a file with the mime-type "text/vcard" using "any" dav path
    But it should not be possible to upload a file with the mime-type "video/webm" using "any" dav path

  Scenario: prohibit file upload for files whose mime type does not begin with a specific string
    When the user places a rule with the filter "File mimetype upload", the operator "doesn't begin with" and the value "audio" in the group named "mime-limiter"
    And the user saves the firewall rules
    Then it should be possible to upload a file with the mime-type "audio/ogg" using "any" dav path
    And it should be possible to upload a file with the mime-type "audio/flac" using "any" dav path
    But it should not be possible to upload a file with the mime-type "video/ogg" using "any" dav path

  Scenario: prohibit file upload for files whose mime type ends with a specific string
    When the user places a rule with the filter "File mimetype upload", the operator "ends with" and the value "mp4" in the group named "mime-limiter"
    And the user saves the firewall rules
    Then it should be possible to upload a file with the mime-type "video/webm" using "any" dav path
    But it should not be possible to upload a file with the mime-type "video/mp4" using "any" dav path
    And it should not be possible to upload a file with the mime-type "audio/mp4" using "any" dav path

  Scenario: prohibit file upload for files whose mime type does not end with a specific string
    When the user places a rule with the filter "File mimetype upload", the operator "doesn't end with" and the value "ogg" in the group named "mime-limiter"
    And the user saves the firewall rules
    Then it should be possible to upload a file with the mime-type "audio/ogg" using "any" dav path
    And it should be possible to upload a file with the mime-type "video/ogg" using "any" dav path
    But it should not be possible to upload a file with the mime-type "video/mpeg" using "any" dav path

  Scenario: prohibit file upload for files of a certain mime type
    When the user places a rule with the filter "File mimetype upload", the operator "is" and the value "text/plain" in the group named "mime-limiter"
    And the user saves the firewall rules
    Then it should not be possible to upload a file with the mime-type "text/plain" using "any" dav path on the last created public link
    But it should be possible to upload a file with the mime-type "image/jpeg" using "any" dav path on the last created public link

  Scenario: prohibit file upload for files of a certain mime type (use chunking to upload)
    When the user places a rule with the filter "File mimetype upload", the operator "is" and the value "text/plain" in the group named "mime-limiter"
    And the user saves the firewall rules
    Then it should not be possible to upload a file with the mime-type "text/plain" using "any" dav path and v1 chunking on the last created public link

  Scenario: prohibit file upload for files of a certain mime type (use chunking to upload)
    When the user places a rule with the filter "File mimetype upload", the operator "is" and the value "text/plain" in the group named "mime-limiter"
    And the user saves the firewall rules
    Then it should not be possible to upload a file with the mime-type "text/plain" using "v2" dav path and v2 chunking on the last created public link

  Scenario: prohibit file upload for files that are not of a certain mime type
    When the user places a rule with the filter "File mimetype upload", the operator "is not" and the value "image/bmp" in the group named "mime-limiter"
    And the user saves the firewall rules
    Then it should be possible to upload a file with the mime-type "image/bmp" using "any" dav path
    But it should not be possible to upload a file with the mime-type "application/msword" using "any" dav path on the last created public link

  Scenario: prohibit file upload for files whose mime type begins with a specific string
    When the user places a rule with the filter "File mimetype upload", the operator "begins with" and the value "video" in the group named "mime-limiter"
    And the user saves the firewall rules
    Then it should be possible to upload a file with the mime-type "image/bmp" using "any" dav path on the last created public link
    And it should be possible to upload a file with the mime-type "text/vcard" using "any" dav path on the last created public link
    But it should not be possible to upload a file with the mime-type "video/webm" using "any" dav path on the last created public link

  Scenario: prohibit file upload for files whose mime type does not begin with a specific string
    When the user places a rule with the filter "File mimetype upload", the operator "doesn't begin with" and the value "audio" in the group named "mime-limiter"
    And the user saves the firewall rules
    Then it should be possible to upload a file with the mime-type "audio/ogg" using "any" dav path on the last created public link
    And it should be possible to upload a file with the mime-type "audio/flac" using "any" dav path on the last created public link
    But it should not be possible to upload a file with the mime-type "video/ogg" using "any" dav path on the last created public link

  Scenario: prohibit file upload for files whose mime type ends with a specific string
    When the user places a rule with the filter "File mimetype upload", the operator "ends with" and the value "mp4" in the group named "mime-limiter"
    And the user saves the firewall rules
    Then it should be possible to upload a file with the mime-type "video/webm" using "any" dav path on the last created public link
    But it should not be possible to upload a file with the mime-type "video/mp4" using "any" dav path on the last created public link
    And it should not be possible to upload a file with the mime-type "audio/mp4" using "any" dav path on the last created public link

  Scenario: prohibit file upload for files whose mime type does not end with a specific string
    When the user places a rule with the filter "File mimetype upload", the operator "doesn't end with" and the value "ogg" in the group named "mime-limiter"
    And the user saves the firewall rules
    Then it should be possible to upload a file with the mime-type "audio/ogg" using "any" dav path on the last created public link
    And it should be possible to upload a file with the mime-type "video/ogg" using "any" dav path on the last created public link
    But it should not be possible to upload a file with the mime-type "video/mpeg" using "any" dav path on the last created public link
