@webUI
Feature: LimitUploadBasedOnSize

  Background:
    Given the administrator has logged in using the webUI
    And the user has browsed to the File Firewall settings page
    And the user has created an empty firewall rule group named "size-limiter"
    And user "Alice" has been created with default attributes and skeleton files
    And user "Alice" has created a public link share of file "simple-folder" with uploadwriteonly permissions

  Scenario: limit upload of files greater than a certain size
    When the user places a rule with the filter "File size upload", the operator "greater" and the value "1M" in the group named "size-limiter"
    And the user saves the firewall rules
    Then it should not be possible to upload a file with the size of "2000000" bytes using "any" dav path and any chunking
    But it should be possible to upload a file with the size of "900000" bytes using "any" dav path and any chunking
    And it should be possible to upload a file with the size of "0" bytes using "any" dav path and any chunking

  Scenario: limit upload of files greater than or equal to a certain size
    When the user places a rule with the filter "File size upload", the operator "greater or equal" and the value "500b" in the group named "size-limiter"
    And the user saves the firewall rules
    Then it should not be possible to upload a file with the size of "501" bytes using "any" dav path and any chunking
    And it should not be possible to upload a file with the size of "500" bytes using "any" dav path and any chunking
    But it should be possible to upload a file with the size of "499" bytes using "any" dav path and any chunking
    And it should be possible to upload a file with the size of "0" bytes using "any" dav path and any chunking

  Scenario: limit upload of files less than a certain size
    When the user places a rule with the filter "File size upload", the operator "less" and the value "42k" in the group named "size-limiter"
    And the user saves the firewall rules
    Then it should not be possible to upload a file with the size of "40000" bytes using "any" dav path and any chunking
    And it should not be possible to upload a file with the size of "0" bytes using "any" dav path and any chunking
    But it should be possible to upload a file with the size of "50000" bytes using "any" dav path and no chunking

  Scenario: limit upload of files less than or equal to a certain size
    When the user places a rule with the filter "File size upload", the operator "less or equal" and the value "1k" in the group named "size-limiter"
    And the user saves the firewall rules
    Then it should not be possible to upload a file with the size of "1024" bytes using "any" dav path and any chunking
    And it should not be possible to upload a file with the size of "1023" bytes using "any" dav path and any chunking
    And it should not be possible to upload a file with the size of "0" bytes using "any" dav path and any chunking
    But it should be possible to upload a file with the size of "1025" bytes using "any" dav path and no chunking

  Scenario: limit upload of files greater than a certain size (use async move to upload)
    Given the user has placed a rule with the filter "File size upload", the operator "greater" and the value "10b" in the group named "size-limiter"
    And the user has saved the firewall rules
    And using new DAV path
    And the administrator has enabled async operations
    And user "Brian" has been created with default attributes and skeleton files
    And user "Brian" has created a new chunking upload with id "chunking-42"
    And user "Brian" has uploaded new chunk file "1" with "AAAAA" to id "chunking-42"
    And user "Brian" has uploaded new chunk file "2" with "BBBBB" to id "chunking-42"
    When user "Brian" uploads new chunk file "3" with "CCCCC" to id "chunking-42" using the WebDAV API
    Then the HTTP status code should be "403"
    When user "Brian" moves new chunk file with id "chunking-42" asynchronously to "/myChunkedFile.txt" using the WebDAV API
    Then the HTTP status code should be "202"
    And the oc job status values of last request for user "Brian" should match these regular expressions
      | status | /^finished$/      |
      | fileId | /^[0-9a-z]{20,}$/ |
    #The first two chunks were uploaded correctly and assembled by the async move
    And as "Brian" file "/myChunkedFile.txt" should exist
    And the content of file "/myChunkedFile.txt" for user "Brian" should be "AAAAABBBBB"

  Scenario: limit upload of files greater than a certain size but lie about the size
    When the user places a rule with the filter "File size upload", the operator "greater" and the value "1M" in the group named "size-limiter"
    And the user saves the firewall rules
    Then it should not be possible to upload a file with the size of "2000000" bytes and these http-headers set using "any" dav path and any chunking
      | http-header     | value |
      | OC-TOTAL-LENGTH | 200   |

  Scenario: limit COPY of a file that is bigger than a specified size
    Given the user has uploaded a file named "bigfile" with the size of "2000000" bytes
    And the user has uploaded a file named "smallfile" with the size of "1023000" bytes
    When the user places a rule with the filter "File size upload", the operator "greater" and the value "1M" in the group named "size-limiter"
    And the user saves the firewall rules
    Then it should not be possible to copy the file "bigfile" to "new-bigfile" using "any" dav path
    But it should be possible to copy the file "smallfile" to "new-smallfile" using "any" dav path

  Scenario: limit MOVE of a file that is bigger than a specified size
    Given the user has uploaded a file named "bigfile" with the size of "2000000" bytes
    And the user has uploaded a file named "smallfile" with the size of "1023000" bytes
    When the user places a rule with the filter "File size upload", the operator "greater" and the value "1M" in the group named "size-limiter"
    And the user saves the firewall rules
    Then it should not be possible to move the file "bigfile" to "v1-bigfile" using "any" dav path
    But it should be possible to move the file "smallfile" to "v1-smallfile" using "v1" dav path
    And it should be possible to move the file "v1-smallfile" to "v2-smallfile" using "v2" dav path

  Scenario: limit MOVE of a file that is bigger than a specified size (using async move)
    Given the user has uploaded a file named "bigfile" with the size of "2000000" bytes
    And the user has uploaded a file named "smallfile" with the size of "1023000" bytes
    And the administrator has enabled async operations
    When the user places a rule with the filter "File size upload", the operator "greater" and the value "1M" in the group named "size-limiter"
    And the user saves the firewall rules
    Then it should not be possible to move the file "bigfile" asynchronously to "v1-bigfile" using "any" dav path
    But it should be possible to move the file "smallfile" asynchronously to "v1-smallfile" using "v1" dav path
    And it should be possible to move the file "v1-smallfile" asynchronously to "v2-smallfile" using "v2" dav path

  Scenario: limit upload of files greater than a certain size
    When the user places a rule with the filter "File size upload", the operator "greater" and the value "1M" in the group named "size-limiter"
    And the user saves the firewall rules
    Then it should not be possible to upload a file with the size of "2000000" bytes using "any" dav path and any chunking on the last created public link
    But it should be possible to upload a file with the size of "900000" bytes using "any" dav path and any chunking on the last created public link
    And it should be possible to upload a file with the size of "0" bytes using "any" dav path and any chunking on the last created public link

  Scenario: limit upload of files greater than or equal to a certain size
    When the user places a rule with the filter "File size upload", the operator "greater or equal" and the value "500b" in the group named "size-limiter"
    And the user saves the firewall rules
    Then it should not be possible to upload a file with the size of "501" bytes using "any" dav path and any chunking on the last created public link
    And it should not be possible to upload a file with the size of "500" bytes using "any" dav path and any chunking on the last created public link
    But it should be possible to upload a file with the size of "499" bytes using "any" dav path and any chunking on the last created public link
    And it should be possible to upload a file with the size of "0" bytes using "any" dav path and any chunking on the last created public link

  Scenario: limit upload of files less than a certain size
    When the user places a rule with the filter "File size upload", the operator "less" and the value "42k" in the group named "size-limiter"
    And the user saves the firewall rules
    Then it should not be possible to upload a file with the size of "40000" bytes using "any" dav path and any chunking on the last created public link
    And it should not be possible to upload a file with the size of "0" bytes using "any" dav path and any chunking on the last created public link
    But it should be possible to upload a file with the size of "50000" bytes using "any" dav path and no chunking on the last created public link

  Scenario: limit upload of files less than or equal to a certain size
    When the user places a rule with the filter "File size upload", the operator "less or equal" and the value "1k" in the group named "size-limiter"
    And the user saves the firewall rules
    Then it should not be possible to upload a file with the size of "1024" bytes using "any" dav path and any chunking on the last created public link
    And it should not be possible to upload a file with the size of "1023" bytes using "any" dav path and any chunking on the last created public link
    And it should not be possible to upload a file with the size of "0" bytes using "any" dav path and any chunking on the last created public link
    But it should be possible to upload a file with the size of "1025" bytes using "any" dav path and no chunking on the last created public link
