<?php
/**
 * ownCloud Workflow
 *
 * @author Joas Schilling <nickvergessen@owncloud.com>
 * @copyright 2015 ownCloud, Inc.
 *
 * This code is covered by the ownCloud Commercial License.
 *
 * You should have received a copy of the ownCloud Commercial License
 * along with this program. If not, see <https://owncloud.com/licenses/owncloud-commercial/>.
 *
 */

namespace OCA\Workflow\Tests\Unit\Condition;

use OCA\Workflow\Condition\RuleFactory;
use OCP\AppFramework\App;
use Test\TestCase;

/**
 * Class RuleFactoryTest
 *
 * @group DB
 * @package OCA\Workflow\Tests\Condition
 */
class RuleFactoryTest extends TestCase {

	/** @var RuleFactory */
	protected $factory;

	protected function setUp(): void {
		parent::setUp();

		$app = new App('workflow');
		$this->factory = new RuleFactory($app->getContainer());
	}

	public function dataGetRuleInstance() {
		return [
			['cidr', 'OCA\Workflow\Condition\Rules\CIDR'],
			['cidr6', 'OCA\Workflow\Condition\Rules\CIDR'],
			['devicetype', 'OCA\Workflow\Condition\Rules\DeviceType'],
			['regex', 'OCA\Workflow\Condition\Rules\Regex'],
			['request', 'OCA\Workflow\Condition\Rules\Request'],
			['requesturl', 'OCA\Workflow\Condition\Rules\RequestUrl'],
			['filetype', 'OCA\Workflow\Condition\Rules\FileType'],
			['filesize', 'OCA\Workflow\Condition\Rules\FileSize'],
			['subnet', 'OCA\Workflow\Condition\Rules\SubNet'],
			['subnet6', 'OCA\Workflow\Condition\Rules\SubNet'],
			['systemtag', 'OCA\Workflow\Condition\Rules\SystemTag'],
			['time', 'OCA\Workflow\Condition\Rules\Time'],
			['useragent', 'OCA\Workflow\Condition\Rules\UserAgent'],
			['usergroup', 'OCA\Workflow\Condition\Rules\UserGroup'],
		];
	}

	/**
	 * @dataProvider dataGetRuleInstance
	 *
	 * @param string $ruleId
	 * @param string $expectedClass
	 */
	public function testGetRuleInstance($ruleId, $expectedClass) {
		$service = $this->factory->getRuleInstance($ruleId);
		$this->assertInstanceOf($expectedClass, $service);
		$this->assertInstanceOf('OCA\Workflow\Condition\Rules\BaseRule', $service);
	}

	/**
	 * @expectedMessage Unknown workflow rule id "Does Not Exist"
	 */
	public function testGetRuleInstanceInvalid() {
		$this->expectException(\InvalidArgumentException::class);

		$this->factory->getRuleInstance('Does Not Exist');
	}

	public function testGetRules() {
		$rules = [
			'cidr',
			'cidr6',
			'devicetype',
			'regex',
			'request',
			'requesturl',
			'filetype',
			'filesize',
			'subnet',
			'subnet6',
			'systemtag',
			'time',
			'useragent',
			'usergroup',
		];

		$actual = $this->factory->getRules();
		$this->assertIsArray($actual);
		$this->assertCount(\sizeof($rules), $actual);

		foreach ($rules as $rule) {
			$this->assertTrue(\in_array($rule, $actual), 'Asserting that rule is returned');
		}
	}
}
