<?php
/**
 * ownCloud Workflow
 *
 * @author Joas Schilling <nickvergessen@owncloud.com>
 * @copyright 2015 ownCloud, Inc.
 *
 * This code is covered by the ownCloud Commercial License.
 *
 * You should have received a copy of the ownCloud Commercial License
 * along with this program. If not, see <https://owncloud.com/licenses/owncloud-commercial/>.
 *
 */

namespace OCA\Workflow\Tests\Unit\Condition\Rules;

use OCA\Workflow\Condition\Operators;
use Test\TestCase;

abstract class BaseRule extends TestCase {

	/** @var \OCA\Workflow\Condition\Operators */
	protected $operators;

	/** @var \OCA\Workflow\Condition\Rules\BaseRule */
	protected $rule;

	/** @var \OCA\Workflow\Condition\Context|\PHPUnit\Framework\MockObject\MockObject */
	protected $context;

	public function setUp(): void {
		parent::setUp();

		$this->operators = new Operators();

		$this->context = $this->getMockBuilder('OCA\Workflow\Condition\Context')
			->disableOriginalConstructor()
			->getMock();

		$class = $this->getRuleClass();
		if ($class !== null) {
			$this->rule = new $class(
				$this->operators,
				$this->context
			);
		}
	}

	/**
	 * @return string|null
	 */
	abstract protected function getRuleClass();

	/**
	 * @return array
	 */
	abstract public function dataValidateRuleValue();

	/**
	 * @dataProvider dataValidateRuleValue
	 *
	 * @param mixed $value
	 * @param bool $throws
	 */
	public function testValidateRuleValue($value, $throws) {
		try {
			$this->rule->validateRuleValue($value, 'test');
			$this->assertFalse($throws);
		} catch (\OutOfBoundsException $e) {
			$this->assertTrue($throws, $e->getMessage());
		}
	}

	public function testGetValidValues() {
		$value = $this->rule->getValidValues();

		$this->assertTrue(\is_array($value) || ($value === null));
	}

	public function testGetValidOperators() {
		$validOperators = $this->invokePrivate($this->rule, 'getValidOperators');
		$this->assertIsArray($validOperators, 'Asserting that getValidOperators returns an array');
		$this->assertNotEmpty($validOperators, 'Asserting that getValidOperators does not return an empty array');

		foreach ($validOperators as $operator) {
			if ($operator !== 'between') {
				$this->assertTrue(\method_exists($this->operators, $operator), 'Asserting that the operator exists');
			} else {
				$this->assertSame('\OCA\Workflow\Condition\Rules\Time', $this->getRuleClass(), 'Asserting that between operator is only allowed for Time');
			}
		}
	}
}
