<?php
/**
 * ownCloud Workflow
 *
 * @author Joas Schilling <nickvergessen@owncloud.com>
 * @copyright 2015 ownCloud, Inc.
 *
 * This code is covered by the ownCloud Commercial License.
 *
 * You should have received a copy of the ownCloud Commercial License
 * along with this program. If not, see <https://owncloud.com/licenses/owncloud-commercial/>.
 *
 */

namespace OCA\Workflow\Tests\Unit\Condition\Rules;

use OCA\Workflow\Condition\Context;
use OCA\Workflow\Condition\Operators;

class RequestTest extends BaseRule {
	public function dataValidateRuleValue() {
		return [
			[Context::REQUEST_TYPE_PUBLIC, false],
			[Context::REQUEST_TYPE_WEBDAV, false],
			[Context::REQUEST_TYPE_OTHER, false],
			['post', true],
			['get', true],
			['put', true],
			['delete', true],
			['test', true],
			[0, true],
			[42, true],
			[[], true],
			[['test'], true],
			[null, true],
		];
	}

	/**
	 * @return string
	 */
	protected function getRuleClass() {
		return '\OCA\Workflow\Condition\Rules\Request';
	}

	public function dataDoCheck() {
		return [
			[Context::REQUEST_TYPE_PUBLIC, Operators::OPERATOR_EQUALS, true],
			[Context::REQUEST_TYPE_OTHER, Operators::OPERATOR_EQUALS, false],
			[Context::REQUEST_TYPE_WEBDAV, Operators::OPERATOR_EQUALS, false],
			[Context::REQUEST_TYPE_PUBLIC, Operators::OPERATOR_NOT_EQUALS, false],
			[Context::REQUEST_TYPE_OTHER, Operators::OPERATOR_NOT_EQUALS, true],
			[Context::REQUEST_TYPE_WEBDAV, Operators::OPERATOR_NOT_EQUALS, true],
		];
	}

	/**
	 * @dataProvider dataDoCheck
	 *
	 * @param bool $contextValue
	 * @param string $operator
	 * @param bool $expected
	 */
	public function testDoCheck($contextValue, $operator, $expected) {
		$this->context->expects($this->once())
			->method('getRequestType')
			->willReturn($contextValue);

		$this->assertSame($expected, $this->rule->doCheck($operator, Context::REQUEST_TYPE_PUBLIC));
	}
}
