<?php
/**
 * ownCloud Workflow
 *
 * @author Joas Schilling <nickvergessen@owncloud.com>
 * @copyright 2015 ownCloud, Inc.
 *
 * This code is covered by the ownCloud Commercial License.
 *
 * You should have received a copy of the ownCloud Commercial License
 * along with this program. If not, see <https://owncloud.com/licenses/owncloud-commercial/>.
 *
 */

namespace OCA\Workflow\Tests\Unit\Condition\Rules;

use OCA\Workflow\Condition\Operators;

class TimeTest extends BaseRule {
	public function dataValidateRuleValue() {
		return [
			[['03:20 pm', '04:30 pm'], false],

			// Too many
			[['03:20 pm', '04:30 pm', '04:30 pm'], true],
			// Too few
			[['03:20 pm'], true],
			// Invalid formats
			[['03:20 pm', '04:30 pm -0500'], true],
			[['03:20 pm -0500', '04:30 pm'], true],
			[['03:20 vorm.', '04:30 am'], true],
			[['03:20 pm', '04:30 nachm.'], true],

			// Invalid
			['test', true],
			[0, true],
			[42, true],
			[[], true],
			[['test'], true],
			[null, true],
		];
	}

	/**
	 * @return string
	 */
	protected function getRuleClass() {
		return '\OCA\Workflow\Condition\Rules\Time';
	}

	public function dataDoCheck() {
		return [
			// Normal match
			[
				['03:20 pm', '04:20 pm'],
				1443018600, // '02:30 pm'
				false,
			],
			[
				['03:20 pm', '04:20 pm'],
				1443018600 + 3600, // '03:30 pm'
				true,
			],
			[
				['03:20 pm', '04:20 pm'],
				1443018600 + 2 * 3600, // '04:30 pm'
				false,
			],

			// Over night
			[
				['04:20 pm', '03:20 pm'],
				1443018600, // '02:30 pm'
				true,
			],
			[
				['04:20 pm', '03:20 pm'],
				1443018600 + 3600, // '03:30 pm'
				false,
			],
			[
				['04:20 pm', '03:20 pm'],
				1443018600 + 2 * 3600, // '04:30 pm'
				true,
			],
		];
	}

	/**
	 * @dataProvider dataDoCheck
	 *
	 * @param array $rule
	 * @param int $actual
	 * @param bool $expected
	 */
	public function testDoCheck($rule, $actual, $expected) {
		$this->context->expects($this->once())
			->method('getRequestTime')
			->willReturn($actual);

		$this->assertSame($expected, $this->rule->doCheck(Operators::OPERATOR_EQUALS, $rule));
	}
}
