<?php
/**
 * ownCloud Workflow
 *
 * @author Joas Schilling <nickvergessen@owncloud.com>
 * @copyright 2015 ownCloud, Inc.
 *
 * This code is covered by the ownCloud Commercial License.
 *
 * You should have received a copy of the ownCloud Commercial License
 * along with this program. If not, see <https://owncloud.com/licenses/owncloud-commercial/>.
 *
 */

namespace OCA\Workflow\Tests\Unit\Condition\Rules;

use OCA\Workflow\Condition\Operators;

class UserGroupTest extends BaseRule {
	public function dataValidateRuleValue() {
		return [
			['test', false],
			[0, true],
			[42, true],
			[[], true],
			[['test'], true],
			[null, true],
		];
	}

	/**
	 * @return string
	 */
	protected function getRuleClass() {
		return '\OCA\Workflow\Condition\Rules\UserGroup';
	}

	public function dataInGroup() {
		return [
			// Check if user is in group
			[
				// Groups
				[],
				// Operator
				Operators::OPERATOR_EQUALS,
				// Expected
				false,
			],
			[
				['admin', 'foo', 'bar', 'baz'],
				Operators::OPERATOR_EQUALS,
				false,
			],
			[
				['admin', 'foo', 'bar', 'test_group'],
				Operators::OPERATOR_EQUALS,
				true,
			],
			[
				['test_group', 'foo', 'bar', 'test_group'],
				Operators::OPERATOR_EQUALS,
				true,
			],
			[
				['test_group'],
				Operators::OPERATOR_EQUALS,
				true,
			],

			// Check if user is not in group
			[
				[],
				Operators::OPERATOR_NOT_EQUALS,
				true,
			],
			[
				['admin', 'foo', 'bar', 'baz'],
				Operators::OPERATOR_NOT_EQUALS,
				true,
			],
			[
				['admin', 'foo', 'bar', 'test_group'],
				Operators::OPERATOR_NOT_EQUALS,
				false,
			],
			[
				['test_group', 'foo', 'bar', 'test_group'],
				Operators::OPERATOR_NOT_EQUALS,
				false,
			],
			[
				['test_group'],
				Operators::OPERATOR_NOT_EQUALS,
				false,
			],
		];
	}

	/**
	 * @dataProvider dataInGroup
	 *
	 * @param array $groups
	 * @param string $operator
	 * @param bool $expected
	 */
	public function testInGroup(array $groups, $operator, $expected) {
		$this->context->expects($this->once())
			->method('getUserGroups')
			->willReturn($groups);

		$this->assertSame($expected, $this->rule->doCheck($operator, 'test_group'));
	}
}
